<?php

namespace Drupal\axeptio;

/**
 * Axeptio service interface.
 */
interface AxeptioInterface {

  /**
   * Return the Axeptio ID.
   *
   * @return string|null
   *   The Axeptio ID "clientId".
   */
  public function getId();

  /**
   * Indicate if the cookies is language specific.
   *
   * @return bool
   *   Return true if language specific is enabled.
   */
  public function isLanguageSpecific();

  /**
   * Return the Axeptio cookies version setting "cookiesVersion".
   *
   * @return string|null
   *   Return the Axeptio cookie version "cookiesVersion".
   */
  public function getCookiesVersion($admin = FALSE);

  /**
   * Return the Axeptio cookies duration in day.
   *
   * @return int|null
   *   The cookie duration in day "userCookiesDuration".
   */
  public function getCookiesDuration();

  /**
   * Indicate if the cookie holding choices is HTTPS only.
   *
   * @return bool
   *   Return true if HTTPS only "userCookiesSecure".
   */
  public function getCookiesSecure();

  /**
   * Checks if the module is configured.
   *
   * @return bool
   *   Return true if configured.
   */
  public function isConfigured();

}
